#[non_exhaustive]pub enum HardwareAddress {
Ethernet([u8; 6]),
Ip,
Ieee802154([u8; 8]),
}Expand description
A hardware (link-layer) address, as reported by a driver.
This is #[non_exhaustive] so that address kinds can be added later without
breaking every driver.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Ethernet([u8; 6])
An Ethernet (MAC) address.
Ip
No address, for devices that send and receive bare IP packets.
Ieee802154([u8; 8])
An IEEE 802.15.4 extended (64-bit) address.
Implementations