xarxa-driver

Crates

git

Versions

default

Flavors

Capabilities

Struct Capabilities 

#[non_exhaustive]
pub struct Capabilities { pub medium: Medium, pub max_transmission_unit: usize, pub checksum: ChecksumCapabilities, }
A description of a device’s capabilities.

This is #[non_exhaustive] so that capabilities can be added later without breaking every driver. Drivers live outside this crate and so cannot use a struct expression, they start from Default and overwrite the fields they care about:

let mut caps = Capabilities::default();
caps.max_transmission_unit = 1514;
// caps.medium = Medium::Ethernet; is the default

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
medium: Medium

Medium of the device.

max_transmission_unit: usize

Maximum transmission unit.

The network device is unable to send or receive frames larger than the value returned by this function.

checksum: ChecksumCapabilities

Checksum behavior.

If the network device is capable of verifying or computing checksums for some protocols, it can request that the stack not do so in software to improve performance.