pub struct ChecksumOffload {
pub rx: bool,
pub tx: bool,
}Expand description
Checksum offload capabilities for a given protocol, per direction.
Fields
rx: boolThe device verifies the checksum of received packets.
The stack then does not verify it in software.
tx: boolThe device fills in the checksum of transmitted packets.
The stack then writes the field as zero instead of computing it.
Implementations